@@ -16,3 +16,6 @@ class EnumMeta(type):
 
     def __contains__(cls, x):
         return x in cls.__vals
+
+    def __iter__(cls):
+        return iter(cls.__vals)
